@@ -93,8 +93,8 @@ class TrainData:
     @staticmethod
     def __clean_data(samples: List[LabelledWeatherForecast]) -> List[LabelledWeatherForecast]:
         seen = list()
-        samples = list(filter(lambda sample: seen.append(sample.time_utc) is None if sample.time_utc not in seen else False, samples))
-        samples = [sample for sample in samples if sample.irradiance > 0]
+        samples = list(filter(lambda sample: seen.append(sample.time_utc) is None if sample.time_utc not in seen else False, samples))  # remove duplicates
+        samples = [sample for sample in samples if sample.irradiance > 0]   # remove 0 value records
         return samples
 
     @staticmethod
@@ -126,11 +126,8 @@ class TrainSampleLog:
         self.__dirname = dirname
         self.__last_compaction_time = datetime.now() - timedelta(days=self.COMPACTION_PERIOD_DAYS*2)
 
-    def filename(self, compressed: bool = False):
-        if compressed:
-            fn = os.path.join(self.__dirname, "train.csv.gz")
-        else:
-            fn = os.path.join(self.__dirname, "train.csv")
+    def filename(self):
+        fn = os.path.join(self.__dirname, "train.csv.gz")
         if not exists(fn):
             directory = Path(fn).parent
             if not exists(directory):
@@ -139,8 +136,7 @@ class TrainSampleLog:
 
     def append(self, sample: LabelledWeatherForecast):
         with self.lock:
-            # compressed file
-            compr_fn = self.filename(compressed=True)
+            compr_fn = self.filename()
             with gzip.open(compr_fn, "ab") as file:
                 line = sample.to_csv() + "\n"
                 file.write(line.encode(encoding='UTF-8'))
@@ -152,24 +148,7 @@ class TrainSampleLog:
 
     def all(self) -> TrainData:
         with self.lock:
-            # plain file
-            fn = self.filename()
-            if exists(fn):
-                try:
-                    with open(fn, "rb") as file:
-                        lines = [raw_line.decode('UTF-8').strip() for raw_line in file.readlines()]
-                        samples = []
-                        for line in lines:
-                            try:
-                                samples.append(LabelledWeatherForecast.from_csv(line))
-                            except Exception as e:
-                                logging.warning(e)
-                        return TrainData(samples)
-                except Exception as e:
-                    logging.warning("error occurred loading " + fn + " " + str(e))
-
-            # compressed file
-            compr_fn = self.filename(compressed=True)
+            compr_fn = self.filename()
             if exists(compr_fn):
                 try:
                     with gzip.open(compr_fn, "rb") as file:
@@ -188,7 +167,7 @@ class TrainSampleLog:
     def compact(self, delay_sec:int = 0):
         sleep(delay_sec)
 
-        fn = self.filename(compressed=True)
+        fn = self.filename()
         train_data = self.all()
         min_datetime = datetime.now() - timedelta(days=400)
 
@@ -196,21 +175,15 @@ class TrainSampleLog:
             temp_file = os.path.join(tmp_dir, 'traindata.csv')
             with gzip.open(temp_file, "wb") as file:
                 file.write((LabelledWeatherForecast.csv_header() + "\n").encode(encoding='UTF-8'))
-                num_samples = len(train_data)
                 num_survived = 0
-                previous_sample = None
                 for sample in train_data:
                     expired = sample.time_utc < min_datetime.astimezone(pytz.UTC)
-                    duplicate = False
-                    if previous_sample is not None:
-                        duplicate = previous_sample.time_utc == sample.time_utc
-                    previous_sample = sample
-                    if not expired and not duplicate:
+                    if not expired:
                         num_survived += 1
                         line = sample.to_csv() + "\n"
                         file.write(line.encode(encoding='UTF-8'))
             shutil.move(temp_file, fn)
-            logging.info("train file " + fn + " compacted (" + str(num_samples - num_survived) + " of " + str(num_samples) + " removed)")
+            logging.info("train file " + fn + " compacted")
 
     def __str__(self):
         return "\n".join([sample.to_csv() for sample in self.all()])
